

   MEMBER('email.clw')                                     ! This is a MEMBER module

                     MAP
                       INCLUDE('SENDMAIL.INC'),ONCE        !Local module procedure declarations
                     END


SendMail             PROCEDURE  (ToAddress, Subject, Body, FileName, ReturnRecip, Flags) ! Declare Procedure
!
! Send an email message with optional file attachment.
!
! PARAM ToAddress   The email address the message is going to.
! PARAM Subject     The subject line for the message.
! PARAM Body        The body of the message.
! PARAM FileName    Optional name of a file to attach to the message.
! PARAM ReturnRecip True if a return receipt is desired.
! PARAM Flags       Can be any combination of (including none) MAPI_DIALOG,
!                   MAPI_LOGON_UI, MAPI_NEW_SESSION
!
! RETURN A ULONG error number. Use GetMapiErrorText() to retrieve
!        a plain English error message.
!

                ! Include structures and equates for MapiSendMail
                INCLUDE('emaildef.inc', 'Defines')

! Something to hold our error, if there is one
mError          ULONG

! Declare a Mapi recipient
mrd             GROUP(MapiRecipDesc)
                END

! Declare a Mapi message
mm              GROUP(MapiMessage)
                END

! Declare a MapiFileDesc
mfd             GROUP(MapiFileDesc)
                END

! The outgoing message information
MapiToEmail     CSTRING(255)                        ! To email address
MapiSubject     CSTRING(255)                        ! Subject of the message
MapiBody        CSTRING(4096)                       ! Body of the message
MapiFileName    CSTRING(255)                        ! FileName to attach
MapiFlags       ULONG

  CODE
  ! Assign STRINGS to our CSTRINGS (required by MapiSendMail)
  MapiToEmail =     CLIP(ToAddress)
  MapiSubject =     CLIP(Subject)
  MapiBody =        CLIP(Body)
  MapiFileName =    CLIP(FileName)

  ! Construct a recipient descriptor
  mrd:RecipClass = Mapi_TO
  mrd:Name       = ADDRESS(MapiToEmail)

  ! Construct the message
  mm:Subject    = ADDRESS(MapiSubject)
  mm:NoteText   = ADDRESS(MapiBody)
  mm:Flags      = MapiFlags
  mm:RecipCount = 1
  mm:Recips     = ADDRESS(mrd)

  ! Attach files if there are any
  IF CLIP(FileName) <> ''

    ! Construct the file attachment
    mfd:PathName    = ADDRESS(MapiFileName)
    mm:FileCount    = 1
    mm:Files        = ADDRESS(mfd)

  ! Nothing to attach
  ELSE
    mm:FileCount =      0
    mm:Files =          0
  END

  ! Send the message
  mError = MapiSendMail(  0, |                    ! session
                          0, |                    ! window
                          ADDRESS(mm), |          ! message
                          Flags, |                ! flags
                          0)                      ! reserved

  RETURN mError

GetMapiErrorText     PROCEDURE  (ErrorNumber)              ! Declare Procedure
!
! Translate an error number into an error message/
!
! PARAM ErrorNumber An error number returned from MapiSendMail.
! RETURN An error message will be returned, if one is defined.
!
!

NUMBER_OF_ERRORS    EQUATE(26)
ERROR_TEXT_LENGTH   EQUATE(50)

! An array to hold the error messages
MapiErrorText    STRING(ERROR_TEXT_LENGTH),DIM(NUMBER_OF_ERRORS)

  CODE
  MapiErrorText[1]  = 'Mapi Error User Abort'
  MapiErrorText[2]  = 'Mapi Error Failure'
  MapiErrorText[3]  = 'Mapi Error Logon Failure'
  MapiErrorText[4]  = 'Mapi Error Disk Full'
  MapiErrorText[5]  = 'Mapi Error Insufficient Memory'
  MapiErrorText[6]  = 'Mapi Error Access Denied'
  MapiErrorText[7]  = 'Mapi Error Error Not Defined'
  MapiErrorText[8]  = 'Mapi Error Too Many Sessions'
  MapiErrorText[9]  = 'Mapi Error Too Many Files'
  MapiErrorText[10] = 'Mapi Error Too Many Recipients'
  MapiErrorText[11] = 'Mapi Error Attachment Not Found'
  MapiErrorText[12] = 'Mapi Error Attachment Open Failure'
  MapiErrorText[13] = 'Mapi Error Attachment Write Failure'
  MapiErrorText[14] = 'Mapi Error Unknown Recipient'
  MapiErrorText[15] = 'Mapi Error Bad Reciptype'
  MapiErrorText[16] = 'Mapi Error No Messages'
  MapiErrorText[17] = 'Mapi Error Invalid Message'
  MapiErrorText[18] = 'Mapi Error Text Too Large'
  MapiErrorText[19] = 'Mapi Error Invalid Session'
  MapiErrorText[20] = 'Mapi Error Type Not Supported'
  MapiErrorText[21] = 'Mapi Error Ambiguous Recipient'
  MapiErrorText[22] = 'Mapi Error Message In Use'
  MapiErrorText[23] = 'Mapi Error Network Failure'
  MapiErrorText[24] = 'Mapi Error Invalid Editfields'
  MapiErrorText[25] = 'Mapi Error Invalid Recips'
  MapiErrorText[26] = 'Mapi Error Not Supported'

  CASE ErrorNumber
  OF 0
    RETURN 'Success'
  OF 1 TO NUMBER_OF_ERRORS
    RETURN MapiErrorText[ErrorNumber]
  END

  RETURN 'Mapi Error Text for ' & ErrorNumber & ' is not defined'

